pub enum AccountKeysResponseParseError {
MissingField(MissingFieldError),
MalformedField,
InconsistentState,
}Expand description
Errors that can occur when parsing a PrivateKeysResponseModel into a
WrappedAccountCryptographicState.
Variants
MissingField(MissingFieldError)
A required field was missing from the API response.
MalformedField
A field value could not be parsed into the expected type.
InconsistentState
The encryption type of the private key does not match the presence/absence of V2 fields.